@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Carp qw/ croak /;
 
-our $VERSION = '0.0400.0';
+our $VERSION = '0.0401.0';
 
 our $COMMON_DATA;
 our $EDITIONS_DATA;
@@ -13,7 +13,7 @@ our $SRC_DATA;
 
 =head1 NAME
 
-HTML::Dojo - Provides the Dojo JavaScript / AJAX distribution 0.4.0 files.
+HTML::Dojo - Provides the Dojo JavaScript / AJAX distribution 0.4.1 files.
 
 =head1 SYNOPSIS
 
@@ -103,10 +103,14 @@ The current editions available are:
 
 =item browserio
 
+=item charting
+
 =item core
 
 =item dashboard
 
+=item dojoWebsite
+
 =item editor
 
 =item event
@@ -119,8 +123,14 @@ The current editions available are:
 
 =item minimal
 
+=item moxie
+
+=item storage
+
 =item widget
 
+=item xdomain-ajax
+
 =over
 
 =cut
@@ -129,15 +139,20 @@ sub editions {
     return qw/
         ajax
         browserio
+        charting
         core
         dashboard
+        dojoWebsite
         editor
         event
         event_and_io
         kitchen_sink
         lfx
         minimal
+        moxie
+        storage
         widget
+        xdomain-ajax
     /;
 }
 
