@@ -421,7 +421,7 @@ problems. You're most likely to find them at:
 
     irc.freenode.net #dojo
 
-Note that 2PM Wed PST in this channel is reserved for a weekly meeting between
+Note that 3PM Wed PST in #dojo-meeting is reserved for a weekly meeting between
 project developers, although anyone is welcome to participate.
 
 
@@ -512,20 +512,20 @@ The text of the AFL and BSD licenses is reproduced below.
 The "New" BSD License:
 **********************
 
-Copyright (c) 2005, The Dojo Foundation
+Copyright (c) 2005-2006, The Dojo Foundation
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:
 
   * Redistributions of source code must retain the above copyright notice, this
-	list of conditions and the following disclaimer.
+    list of conditions and the following disclaimer.
   * Redistributions in binary form must reproduce the above copyright notice,
-	this list of conditions and the following disclaimer in the documentation
-	and/or other materials provided with the distribution.
+    this list of conditions and the following disclaimer in the documentation
+    and/or other materials provided with the distribution.
   * Neither the name of the Dojo Foundation nor the names of its contributors
-	may be used to endorse or promote products derived from this software
-	without specific prior written permission.
+    may be used to endorse or promote products derived from this software
+    without specific prior written permission.
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
